""" This module contains the function to calculate the hash of a value and a secret."""
import hashlib


def calculate_hash(value: bytes, secret: bytes) -> str:
    """ This function calculates the hash of a value and a secret.  
    It is used to verify that the message is from the server. The hash 
    is calculated using the SHA512 algorithm. The hash is returned as a
    hex string. This is not a secure hash, but it is good enough for
    this application.      

    parameters:
        value: The value to hash.
        secret: The secret to hash with the value.
    returns:
        The hash of the value and secret.  This is a hex string.
    """
    sha512 = hashlib.sha512()
    sha512.update(b"".join([value, secret]))
    return sha512.hexdigest()
